@@ -5,7 +5,7 @@ except ImportError:  # Python 2
     import httplib
     from urlparse import parse_qsl
 
-from .exceptions import QuickbooksException, SevereException
+from .exceptions import QuickbooksException, SevereException, AuthorizationException
 
 try:
     from rauth import OAuth1Session, OAuth1Service
@@ -52,41 +52,64 @@ class QuickBooks(object):
     ]
 
     __instance = None
+    __use_global = False
 
     def __new__(cls, **kwargs):
-        if QuickBooks.__instance is None:
-            QuickBooks.__instance = object.__new__(cls)
+        """
+        If global is disabled, don't set global client instance.
+        """
+        if QuickBooks.__use_global:
+            if QuickBooks.__instance is None:
+                QuickBooks.__instance = object.__new__(cls)
+            instance = QuickBooks.__instance
+        else:
+            instance = object.__new__(cls)
 
         if 'consumer_key' in kwargs:
-            cls.consumer_key = kwargs['consumer_key']
+            instance.consumer_key = kwargs['consumer_key']
 
         if 'consumer_secret' in kwargs:
-            cls.consumer_secret = kwargs['consumer_secret']
+            instance.consumer_secret = kwargs['consumer_secret']
 
         if 'access_token' in kwargs:
-            cls.access_token = kwargs['access_token']
+            instance.access_token = kwargs['access_token']
 
         if 'access_token_secret' in kwargs:
-            cls.access_token_secret = kwargs['access_token_secret']
+            instance.access_token_secret = kwargs['access_token_secret']
 
         if 'company_id' in kwargs:
-            cls.company_id = kwargs['company_id']
+            instance.company_id = kwargs['company_id']
 
         if 'callback_url' in kwargs:
-            cls.callback_url = kwargs['callback_url']
+            instance.callback_url = kwargs['callback_url']
 
         if 'sandbox' in kwargs:
-            cls.sandbox = kwargs['sandbox']
+            instance.sandbox = kwargs['sandbox']
 
         if 'minorversion' in kwargs:
-            cls.minorversion = kwargs['minorversion']
+            instance.minorversion = kwargs['minorversion']
 
-        return QuickBooks.__instance
+        return instance
 
     @classmethod
     def get_instance(cls):
         return cls.__instance
 
+    @classmethod
+    def disable_global(cls):
+        """
+        Disable use of singleton pattern.
+        """
+        QuickBooks.__use_global = False
+        QuickBooks.__instance = None
+
+    @classmethod
+    def enable_global(cls):
+        """
+        Allow use of singleton pattern.
+        """
+        QuickBooks.__use_global = True
+
     def _drop(self):
         QuickBooks.__instance = None
 
@@ -116,6 +139,7 @@ class QuickBooks(object):
         Returns the Authorize URL as returned by QB, and specified by OAuth 1.0a.
         :return URI:
         """
+        self.authorize_url = self.authorize_url[:self.authorize_url.find('?')] if '?' in self.authorize_url else self.authorize_url
         if self.qbService is None:
             self.set_up_service()
 
@@ -157,7 +181,6 @@ class QuickBooks(object):
         return session
 
     def make_request(self, request_type, url, request_body=None, content_type='application/json'):
-
         params = {}
 
         if self.minorversion:
@@ -175,14 +198,19 @@ class QuickBooks(object):
         }
 
         req = self.session.request(request_type, url, True, self.company_id, headers=headers, params=params, data=request_body)
+        if req.status_code == httplib.UNAUTHORIZED:
+            raise AuthorizationException("Application authentication failed", detail=req.text)
 
         try:
             result = req.json()
         except:
             raise QuickbooksException("Error reading json response: {0}".format(req.text), 10000)
 
-        if req.status_code is not httplib.OK or "Fault" in result:
+        if "Fault" in result:
             self.handle_exceptions(result["Fault"])
+        elif not req.status_code == httplib.OK:
+            raise QuickbooksException("Error returned with status code '{0}': {1}".format(
+                req.status_code, req.text), 10000)
         else:
             return result
 
