@@ -9,12 +9,12 @@ class Item(QuickbooksManagedObject, QuickbooksTransactionEntity):
     An item is shown as a line on an invoice or other sales form. The Item.Type attribute, which specifies how
     the item is used, has one of the following values:
 
-       Inventory - This type tracks merchandise that your business purchases, stocks, and re-sells as inventory.
-       QuickBooks tracks the current number of inventory items in stock, cost of goods sold, and the asset value of
-       the inventory after the purchase and sale of every item.
+    Inventory - This type tracks merchandise that your business purchases, stocks, and re-sells as inventory.
+    QuickBooks tracks the current number of inventory items in stock, cost of goods sold, and the asset value of
+    the inventory after the purchase and sale of every item.
 
-       Service - This type tracks services that you charge on the purchase and tracks merchandise you sell and buy that
-       is not tracked as inventory. For example, specialized labor, consulting hours, and professional fees.
+    Service - This type tracks services that you charge on the purchase and tracks merchandise you sell and buy that
+    is not tracked as inventory. For example, specialized labor, consulting hours, and professional fees.
     """
 
     class_dict = {
@@ -31,27 +31,21 @@ class Item(QuickbooksManagedObject, QuickbooksTransactionEntity):
     def __init__(self):
         super(Item, self).__init__()
         self.Name = ""
-        self.Sku = ""
         self.Description = ""
         self.Active = True
         self.SubItem = False
-        self.FullyQualifiedName = ""
+        self.FullyQualifiedName = ""  # Readonly
         self.Taxable = False
-        self.SalesTaxInclusive = False
-        self.UnitPrice = ""
-        self.Type = "Inventory"
-        self.ItemCategoryType = "Product"
-        self.Level = 0
-        self.PurchaseDesc = ""
-        self.PurchaseTaxInclusive = False
-        self.PurchaseCost = 0
+        self.SalesTaxInclusive = None
+        self.UnitPrice = 0
+        self.Type = ""
+        self.Level = None  # Readonly
+        self.PurchaseDesc = None
+        self.PurchaseTaxInclusive = None
+        self.PurchaseCost = None
         self.TrackQtyOnHand = False
-        self.QtyOnHand = 0
-        self.InvStartDate = ""
-
-        self.AbatementRate = ""
-        self.ReverseChargeRate = ""
-        self.ServiceType = ""
+        self.QtyOnHand = None
+        self.InvStartDate = None
 
         self.AssetAccountRef = None
         self.ExpenseAccountRef = None
@@ -60,6 +54,15 @@ class Item(QuickbooksManagedObject, QuickbooksTransactionEntity):
         self.ParentRef = None
         self.PurchaseTaxCodeRef = None
 
+        # These fields are for minor version 3
+        self.AbatementRate = None
+        self.ReverseChargeRate = None
+        self.ServiceType = None
+        self.ItemCategoryType = None
+
+        # These fields are for minor version 4
+        self.Sku = None
+
     def __str__(self):
         return self.Name
 
