@@ -43,7 +43,7 @@ class PurchaseOrderLine(QuickbooksBaseObject):
 
     def __init__(self):
         super(PurchaseOrderLine, self).__init__()
-        self.Id = 0
+        self.Id = None
         self.LineNum = 0
         self.Description = ""
         self.Amount = 0
